import React, { useState } from 'react';
import { Link, useNavigate, useParams } from 'react-router-dom';
import SvgIcon from '../../components/SvgIcon';

export default function ChatSidebar({ chatHistory = [], onDeleteChat, isLoading = false, hasError = false }) {
    const navigate = useNavigate();
    const { chatId, knowledgeBaseId } = useParams();
    const [activeDropdown, setActiveDropdown] = useState(null);

    const handleNewChat = () => {
        navigate('/chat');
    };

    const handleMouseEnter = (id) => {
        setActiveDropdown(id);
    };

    const handleMouseLeave = () => {
        setActiveDropdown(null);
    };

    const handleDeleteChat = (e, id) => {
        e.preventDefault();
        e.stopPropagation();
        if (onDeleteChat) {
            onDeleteChat(id);
        }
        setActiveDropdown(null);
    };

    // 渲染加载状态
    const renderLoading = () => (
        <div className='p-3 text-center'>
            <div className='spinner-border spinner-border-sm text-secondary' role='status'>
                <span className='visually-hidden'>加载中...</span>
            </div>
            <div className='mt-2 text-muted small'>加载聊天记录...</div>
        </div>
    );

    // 渲染错误状态
    const renderError = () => (
        <div className='p-3 text-center'>
            <div className='text-danger mb-2'>
                <SvgIcon className='error' width='24' height='24' />
            </div>
            <div className='text-muted small'>加载聊天记录失败，请重试</div>
        </div>
    );

    // 渲染空状态
    const renderEmpty = () => (
        <div className='p-3 text-center'>
            <div className='text-muted small'>暂无聊天记录</div>
        </div>
    );

    return (
        <div className='chat-sidebar d-flex flex-column h-100'>
            <div className='p-3 pb-0'>
                <h5 className='mb-0'>聊天记录</h5>
            </div>

            <div className='p-3'>
                <button
                    className='btn btn-dark w-100 d-flex align-items-center justify-content-center gap-2'
                    onClick={handleNewChat}
                >
                    <SvgIcon className='plus' color='#ffffff' />
                    <span>新建聊天</span>
                </button>
            </div>

            <div className='overflow-auto flex-grow-1'>
                {isLoading ? (
                    renderLoading()
                ) : hasError ? (
                    renderError()
                ) : chatHistory.length === 0 ? (
                    renderEmpty()
                ) : (
                    <ul className='list-group list-group-flush'>
                        {chatHistory.map((chat) => (
                            <li
                                key={chat.conversation_id}
                                className={`list-group-item border-0 position-relative ${
                                    chatId === chat.conversation_id ? 'bg-light' : ''
                                }`}
                            >
                                <Link
                                    to={`/chat/${chat.datasets?.[0]?.id || knowledgeBaseId}/${chat.conversation_id}`}
                                    className={`text-decoration-none d-flex align-items-center gap-2 py-2 text-dark ${
                                        chatId === chat.conversation_id ? 'fw-bold' : ''
                                    }`}
                                >
                                    <div className='d-flex flex-column'>
                                        <div className='text-truncate fw-medium'>
                                            {chat.datasets?.map((ds) => ds.name).join(', ') || '未命名知识库'}
                                        </div>
                                    </div>
                                </Link>
                                <div
                                    className='dropdown-hover-area position-absolute end-0 top-0 bottom-0'
                                    style={{ width: '40px' }}
                                    onMouseEnter={() => handleMouseEnter(chat.conversation_id)}
                                    onMouseLeave={handleMouseLeave}
                                >
                                    <button className='btn btn-sm position-absolute end-0 top-50 translate-middle-y me-2'>
                                        <SvgIcon className='more-dot' width='5' height='16' />
                                    </button>
                                    {activeDropdown === chat.conversation_id && (
                                        <div
                                            className='position-absolute end-0 top-100 bg-white shadow rounded p-1 z-3'
                                            style={{ zIndex: 1000, minWidth: '80px' }}
                                        >
                                            <button
                                                className='btn btn-sm text-danger d-flex align-items-center gap-2 w-100'
                                                onClick={(e) => handleDeleteChat(e, chat.conversation_id)}
                                            >
                                                <SvgIcon className='trash' />
                                                <span>删除</span>
                                            </button>
                                        </div>
                                    )}
                                </div>
                            </li>
                        ))}
                    </ul>
                )}
            </div>
        </div>
    );
}
