import { createSlice } from '@reduxjs/toolkit';
import {
    fetchUserPermissions,
    updateUserPermissions,
    fetchPermissionsThunk,
    approvePermissionThunk,
    rejectPermissionThunk,
    fetchAllUserPermissions,
} from './permissions.thunks';

const initialState = {
    users: {
        items: [],
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    allUsersPermissions: {
        results: [],
        total: 0,
        page: 1,
        page_size: 10,
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    operations: {
        status: 'idle',
        error: null,
    },
    pending: {
        results: [], // 更改为results
        total: 0, // 添加total
        page: 1, // 添加page
        page_size: 10, // 添加page_size
        status: 'idle',
        error: null,
    },
    approveReject: {
        status: 'idle',
        error: null,
        currentId: null,
    },
};

const permissionsSlice = createSlice({
    name: 'permissions',
    initialState,
    reducers: {
        resetOperationStatus: (state) => {
            state.operations.status = 'idle';
            state.operations.error = null;
        },
    },
    extraReducers: (builder) => {
        builder
            // 获取用户权限列表
            .addCase(fetchUserPermissions.pending, (state) => {
                state.users.status = 'loading';
                state.users.error = null;
            })
            .addCase(fetchUserPermissions.fulfilled, (state, action) => {
                state.users.status = 'succeeded';
                state.users.items = action.payload;
            })
            .addCase(fetchUserPermissions.rejected, (state, action) => {
                state.users.status = 'failed';
                state.users.error = action.error.message;
            })

            // 更新用户权限
            .addCase(updateUserPermissions.pending, (state) => {
                state.operations.status = 'loading';
                state.operations.error = null;
            })
            .addCase(updateUserPermissions.fulfilled, (state, action) => {
                state.operations.status = 'succeeded';
                // 更新用户列表中的权限信息
                const index = state.users.items.findIndex((user) => user.id === action.payload.userId);
                if (index !== -1) {
                    state.users.items[index] = {
                        ...state.users.items[index],
                        permissions: action.payload.permissions,
                    };
                }
            })
            .addCase(updateUserPermissions.rejected, (state, action) => {
                state.operations.status = 'failed';
                state.operations.error = action.error.message;
            })

            // 获取待处理申请列表
            .addCase(fetchPermissionsThunk.pending, (state) => {
                state.pending.status = 'loading';
                state.pending.error = null;
            })
            .addCase(fetchPermissionsThunk.fulfilled, (state, action) => {
                state.pending.status = 'succeeded';
                state.pending.results = action.payload.results || [];
                state.pending.total = action.payload.total || 0;
                state.pending.page = action.payload.page || 1;
                state.pending.page_size = action.payload.page_size || 10;
            })
            .addCase(fetchPermissionsThunk.rejected, (state, action) => {
                state.pending.status = 'failed';
                state.pending.error = action.error.message;
            })

            // 批准/拒绝权限申请
            .addCase(approvePermissionThunk.pending, (state, action) => {
                state.approveReject.status = 'loading';
                state.approveReject.error = null;
                state.approveReject.currentId = action.meta.arg.id;
            })
            .addCase(approvePermissionThunk.fulfilled, (state) => {
                state.approveReject.status = 'succeeded';
                state.approveReject.currentId = null;
            })
            .addCase(approvePermissionThunk.rejected, (state, action) => {
                state.approveReject.status = 'failed';
                state.approveReject.error = action.error.message;
                state.approveReject.currentId = null;
            })

            .addCase(rejectPermissionThunk.pending, (state, action) => {
                state.approveReject.status = 'loading';
                state.approveReject.error = null;
                state.approveReject.currentId = action.meta.arg.id;
            })
            .addCase(rejectPermissionThunk.fulfilled, (state) => {
                state.approveReject.status = 'succeeded';
                state.approveReject.currentId = null;
            })
            .addCase(rejectPermissionThunk.rejected, (state, action) => {
                state.approveReject.status = 'failed';
                state.approveReject.error = action.error.message;
                state.approveReject.currentId = null;
            })

            // 获取所有用户及其权限列表
            .addCase(fetchAllUserPermissions.pending, (state) => {
                state.allUsersPermissions.status = 'loading';
                state.allUsersPermissions.error = null;
            })
            .addCase(fetchAllUserPermissions.fulfilled, (state, action) => {
                state.allUsersPermissions.status = 'succeeded';
                state.allUsersPermissions.results = action.payload.results || [];
                state.allUsersPermissions.total = action.payload.total || 0;
                state.allUsersPermissions.page = action.payload.page || 1;
                state.allUsersPermissions.page_size = action.payload.page_size || 10;
            })
            .addCase(fetchAllUserPermissions.rejected, (state, action) => {
                state.allUsersPermissions.status = 'failed';
                state.allUsersPermissions.error = action.payload || action.error.message;
            });
    },
});

export const { resetOperationStatus } = permissionsSlice.actions;

export default permissionsSlice.reducer;
